# Sharding

::: casty.ClusteredActorSystem

::: casty.ShardedBehavior

::: casty.ShardEnvelope

::: casty.ReplicationConfig

::: casty.ShardAllocation

::: casty.ReplicateEvents

::: casty.ReplicateEventsAck

::: casty.ReplicaPromoted
